@@ -223,6 +223,7 @@ def bli(pairs, e, precision=[1,5,15], reverse=False):
     rows = []
     for i in range(A.shape[1]):
         target_word = target_words[i]
+        source_word = source_words[i]
         y_hat = A[:,i]
         _, tops = tf.math.top_k(y_hat, k=max(precision))
         topwords = [target_vocab[i] for i in tops]
@@ -232,8 +233,8 @@ def bli(pairs, e, precision=[1,5,15], reverse=False):
             x = target_word in topwords_p
             row_correct.append(x)
 
-        row = [target_word] + row_correct + topwords
+        row = [source_word, target_word] + row_correct + topwords
         rows.append(row)
 
-    columns = ["target"] + [f"p@{p}" for p in precision] + [f"guess-{g}" for g in range(max(precision))]
+    columns = ["source", "target"] + [f"p@{p}" for p in precision] + [f"guess-{g}" for g in range(max(precision))]
     return pd.DataFrame(rows, columns=columns)
